@@ -14,36 +14,36 @@
 /*	const char *relay;
 /*	DSN	*dsn;
 /*
-/*	int	bounce_flush(flags, queue, id, encoding, smtputf8, sender,
+/*	int	bounce_flush(flags, queue, id, encoding, sendopts, sender,
 /*				dsn_envid, dsn_ret)
 /*	int	flags;
 /*	const char *queue;
 /*	const char *id;
 /*	const char *encoding;
-/*	int	smtputf8;
+/*	int	sendopts;
 /*	const char *sender;
 /*	const char *dsn_envid;
 /*	int	dsn_ret;
 /*
-/*	int	bounce_flush_verp(flags, queue, id, encoding, smtputf8,
+/*	int	bounce_flush_verp(flags, queue, id, encoding, sendopts,
 /*				sender, dsn_envid, dsn_ret, verp_delims)
 /*	int	flags;
 /*	const char *queue;
 /*	const char *id;
 /*	const char *encoding;
-/*	int	smtputf8;
+/*	int	sendopts;
 /*	const char *sender;
 /*	const char *dsn_envid;
 /*	int	dsn_ret;
 /*	const char *verp_delims;
 /*
-/*	int	bounce_one(flags, queue, id, encoding, smtputf8, sender,
+/*	int	bounce_one(flags, queue, id, encoding, sendopts, sender,
 /*				dsn_envid, ret, stats, recipient, relay, dsn)
 /*	int	flags;
 /*	const char *queue;
 /*	const char *id;
 /*	const char *encoding;
-/*	int	smtputf8;
+/*	int	sendopts;
 /*	const char *sender;
 /*	const char *dsn_envid;
 /*	int	dsn_ret;
@@ -65,13 +65,13 @@
 /*	RECIPIENT *rcpt;
 /*	const char *relay;
 /*
-/*	int	bounce_one_intern(flags, queue, id, encoding, smtputf8, sender,
+/*	int	bounce_one_intern(flags, queue, id, encoding, sendopts, sender,
 /*				dsn_envid, ret, stats, recipient, relay, dsn)
 /*	int	flags;
 /*	const char *queue;
 /*	const char *id;
 /*	const char *encoding;
-/*	int	smtputf8;
+/*	int	sendopts;
 /*	const char *sender;
 /*	const char *dsn_envid;
 /*	int	dsn_ret;
@@ -151,8 +151,8 @@
 /*	This information is used for syslogging only.
 /* .IP encoding
 /*	The body content encoding: MAIL_ATTR_ENC_{7BIT,8BIT,NONE}.
-/* .IP smtputf8
-/*	The level of SMTPUTF8 support (to be defined).
+/* .IP sendopts
+/*	Sender-requested SMTPUTF8 or RequireTLS support.
 /* .IP sender
 /*	The sender envelope address.
 /* .IP dsn_envid
@@ -191,6 +191,9 @@
 /*	Google, Inc.
 /*	111 8th Avenue
 /*	New York, NY 10011, USA
+/*
+/*	Wietse Venema
+/*	porcupine.org
 /*--*/
 
 /* System library. */
@@ -347,7 +350,7 @@ int     bounce_append_intern(int flags, const char *id, MSG_STATS *stats,
 /* bounce_flush - flush the bounce log and deliver to the sender */
 
 int     bounce_flush(int flags, const char *queue, const char *id,
-		             const char *encoding, int smtputf8,
+		             const char *encoding, int sendopts,
 		             const char *sender, const char *dsn_envid,
 		             int dsn_ret)
 {
@@ -365,7 +368,7 @@ int     bounce_flush(int flags, const char *queue, const char *id,
 			    SEND_ATTR_STR(MAIL_ATTR_QUEUE, queue),
 			    SEND_ATTR_STR(MAIL_ATTR_QUEUEID, id),
 			    SEND_ATTR_STR(MAIL_ATTR_ENCODING, encoding),
-			    SEND_ATTR_INT(MAIL_ATTR_SMTPUTF8, smtputf8),
+			    SEND_ATTR_INT(MAIL_ATTR_SENDOPTS, sendopts),
 			    SEND_ATTR_STR(MAIL_ATTR_SENDER, sender),
 			    SEND_ATTR_STR(MAIL_ATTR_DSN_ENVID, dsn_envid),
 			    SEND_ATTR_INT(MAIL_ATTR_DSN_RET, dsn_ret),
@@ -382,7 +385,7 @@ int     bounce_flush(int flags, const char *queue, const char *id,
 /* bounce_flush_verp - verpified notification */
 
 int     bounce_flush_verp(int flags, const char *queue, const char *id,
-			          const char *encoding, int smtputf8,
+			          const char *encoding, int sendopts,
 			          const char *sender, const char *dsn_envid,
 			          int dsn_ret, const char *verp_delims)
 {
@@ -400,7 +403,7 @@ int     bounce_flush_verp(int flags, const char *queue, const char *id,
 			    SEND_ATTR_STR(MAIL_ATTR_QUEUE, queue),
 			    SEND_ATTR_STR(MAIL_ATTR_QUEUEID, id),
 			    SEND_ATTR_STR(MAIL_ATTR_ENCODING, encoding),
-			    SEND_ATTR_INT(MAIL_ATTR_SMTPUTF8, smtputf8),
+			    SEND_ATTR_INT(MAIL_ATTR_SENDOPTS, sendopts),
 			    SEND_ATTR_STR(MAIL_ATTR_SENDER, sender),
 			    SEND_ATTR_STR(MAIL_ATTR_DSN_ENVID, dsn_envid),
 			    SEND_ATTR_INT(MAIL_ATTR_DSN_RET, dsn_ret),
@@ -418,7 +421,7 @@ int     bounce_flush_verp(int flags, const char *queue, const char *id,
 /* bounce_one - send notice for one recipient */
 
 int     bounce_one(int flags, const char *queue, const char *id,
-		           const char *encoding, int smtputf8,
+		           const char *encoding, int sendopts,
 		           const char *sender, const char *dsn_envid,
 		           int dsn_ret, MSG_STATS *stats, RECIPIENT *rcpt,
 		           const char *relay, DSN *dsn)
@@ -443,14 +446,14 @@ int     bounce_one(int flags, const char *queue, const char *id,
 	    return (defer_append_intern(flags, id, stats, rcpt, relay, dsn_res));
 	my_dsn = *dsn_res;
     }
-    return (bounce_one_intern(flags, queue, id, encoding, smtputf8, sender,
+    return (bounce_one_intern(flags, queue, id, encoding, sendopts, sender,
 			  dsn_envid, dsn_ret, stats, rcpt, relay, &my_dsn));
 }
 
 /* bounce_one_intern - send notice for one recipient */
 
 int     bounce_one_intern(int flags, const char *queue, const char *id,
-			          const char *encoding, int smtputf8,
+			          const char *encoding, int sendopts,
 			          const char *sender, const char *dsn_envid,
 			          int dsn_ret, MSG_STATS *stats,
 			          RECIPIENT *rcpt, const char *relay,
@@ -508,7 +511,7 @@ int     bounce_one_intern(int flags, const char *queue, const char *id,
 				SEND_ATTR_STR(MAIL_ATTR_QUEUE, queue),
 				SEND_ATTR_STR(MAIL_ATTR_QUEUEID, id),
 				SEND_ATTR_STR(MAIL_ATTR_ENCODING, encoding),
-				SEND_ATTR_INT(MAIL_ATTR_SMTPUTF8, smtputf8),
+				SEND_ATTR_INT(MAIL_ATTR_SENDOPTS, sendopts),
 				SEND_ATTR_STR(MAIL_ATTR_SENDER, sender),
 			      SEND_ATTR_STR(MAIL_ATTR_DSN_ENVID, dsn_envid),
 				SEND_ATTR_INT(MAIL_ATTR_DSN_RET, dsn_ret),
