@@ -27,9 +27,8 @@
 /*	Time stamps from different message delivery stages
 /*	and session reuse count.
 /* .IP recipient
-/*	Recipient information. See recipient_list(3).
-/* .IP sender
-/*	The sender envelope address.
+/*	Recipient information, see recipient_list(3). The address
+/*	is formatted by the info_log_addr_form(3) routines.
 /* .IP relay
 /*	Host we could (not) talk to.
 /* .IP status
@@ -48,6 +47,11 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
+/*
+/*	Wietse Venema
+/*	Google, Inc.
+/*	111 8th Avenue
+/*	New York, NY 10011, USA
 /*--*/
 
 /* System library. */
@@ -66,6 +70,7 @@
 
 #include <log_adhoc.h>
 #include <mail_params.h>
+#include <info_log_addr_form.h>
 
  /*
   * Don't use "struct timeval" for time differences; use explicit signed
@@ -103,10 +108,12 @@ void    log_adhoc(const char *id, MSG_STATS *stats, RECIPIENT *recipient,
      * First, critical information that identifies the nature of the
      * transaction.
      */
-    vstring_sprintf(buf, "%s: to=<%s>", id, recipient->address);
+    vstring_sprintf(buf, "%s: to=<%s>", id,
+		    info_log_addr_form_recipient(recipient->address));
     if (recipient->orig_addr && *recipient->orig_addr
 	&& strcasecmp_utf8(recipient->address, recipient->orig_addr) != 0)
-	vstring_sprintf_append(buf, ", orig_to=<%s>", recipient->orig_addr);
+	vstring_sprintf_append(buf, ", orig_to=<%s>",
+			info_log_addr_form_recipient(recipient->orig_addr));
     vstring_sprintf_append(buf, ", relay=%s", relay);
     if (stats->reuse_count > 0)
 	vstring_sprintf_append(buf, ", conn_use=%d", stats->reuse_count + 1);
